commit e1111500dafcd00186ae364c90a2e7434b9f9d0e
Author: Leszek Koltunski <leszek@koltunski.pl>
Date:   Thu May 2 23:41:10 2019 +0100

    Rename all the classes that are not exported to application to 'Internal'

diff --git a/distorted-cube.iml b/distorted-cube.iml
index 73a3ac21..8e5a8610 100644
--- a/distorted-cube.iml
+++ b/distorted-cube.iml
@@ -17,7 +17,7 @@
         <option name="ALLOW_USER_CONFIGURATION" value="false" />
         <option name="MANIFEST_FILE_RELATIVE_PATH" value="/src/main/AndroidManifest.xml" />
         <option name="RES_FOLDER_RELATIVE_PATH" value="/src/main/res" />
-        <option name="RES_FOLDERS_RELATIVE_PATH" value="file://$MODULE_DIR$/src/main/res;file://$MODULE_DIR$/build/generated/res/resValues/debug" />
+        <option name="RES_FOLDERS_RELATIVE_PATH" value="file://$MODULE_DIR$/src/main/res" />
         <option name="TEST_RES_FOLDERS_RELATIVE_PATH" value="" />
         <option name="ASSETS_FOLDER_RELATIVE_PATH" value="/src/main/assets" />
       </configuration>
diff --git a/src/main/java/org/distorted/magic/RubikCube.java b/src/main/java/org/distorted/magic/RubikCube.java
index 07790540..ce07628c 100644
--- a/src/main/java/org/distorted/magic/RubikCube.java
+++ b/src/main/java/org/distorted/magic/RubikCube.java
@@ -1,20 +1,20 @@
 ///////////////////////////////////////////////////////////////////////////////////////////////////
 // Copyright 2019 Leszek Koltunski                                                               //
 //                                                                                               //
-// This file is part of Distorted.                                                               //
+// This file is part of DistortedLibrary.                                                               //
 //                                                                                               //
-// Distorted is free software: you can redistribute it and/or modify                             //
+// DistortedLibrary is free software: you can redistribute it and/or modify                             //
 // it under the terms of the GNU General Public License as published by                          //
 // the Free Software Foundation, either version 2 of the License, or                             //
 // (at your option) any later version.                                                           //
 //                                                                                               //
-// Distorted is distributed in the hope that it will be useful,                                  //
+// DistortedLibrary is distributed in the hope that it will be useful,                                  //
 // but WITHOUT ANY WARRANTY; without even the implied warranty of                                //
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                                 //
 // GNU General Public License for more details.                                                  //
 //                                                                                               //
 // You should have received a copy of the GNU General Public License                             //
-// along with Distorted.  If not, see <http://www.gnu.org/licenses/>.                            //
+// along with DistortedLibrary.  If not, see <http://www.gnu.org/licenses/>.                            //
 ///////////////////////////////////////////////////////////////////////////////////////////////////
 
 package org.distorted.magic;
diff --git a/src/main/java/org/distorted/magic/RubikSurfaceView.java b/src/main/java/org/distorted/magic/RubikSurfaceView.java
index d95de4f8..426f407c 100644
--- a/src/main/java/org/distorted/magic/RubikSurfaceView.java
+++ b/src/main/java/org/distorted/magic/RubikSurfaceView.java
@@ -1,20 +1,20 @@
 ///////////////////////////////////////////////////////////////////////////////////////////////////
 // Copyright 2019 Leszek Koltunski                                                               //
 //                                                                                               //
-// This file is part of Distorted.                                                               //
+// This file is part of DistortedLibrary.                                                               //
 //                                                                                               //
-// Distorted is free software: you can redistribute it and/or modify                             //
+// DistortedLibrary is free software: you can redistribute it and/or modify                             //
 // it under the terms of the GNU General Public License as published by                          //
 // the Free Software Foundation, either version 2 of the License, or                             //
 // (at your option) any later version.                                                           //
 //                                                                                               //
-// Distorted is distributed in the hope that it will be useful,                                  //
+// DistortedLibrary is distributed in the hope that it will be useful,                                  //
 // but WITHOUT ANY WARRANTY; without even the implied warranty of                                //
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                                 //
 // GNU General Public License for more details.                                                  //
 //                                                                                               //
 // You should have received a copy of the GNU General Public License                             //
-// along with Distorted.  If not, see <http://www.gnu.org/licenses/>.                            //
+// along with DistortedLibrary.  If not, see <http://www.gnu.org/licenses/>.                            //
 ///////////////////////////////////////////////////////////////////////////////////////////////////
 
 package org.distorted.magic;

diff --git a/src/main/java/org/distorted/magic/RubikActivity.java b/src/main/java/org/distorted/magic/RubikActivity.java
index b3e57dad..bff4a5c9 100644
--- a/src/main/java/org/distorted/magic/RubikActivity.java
+++ b/src/main/java/org/distorted/magic/RubikActivity.java
@@ -1,20 +1,20 @@
 ///////////////////////////////////////////////////////////////////////////////////////////////////
 // Copyright 2019 Leszek Koltunski                                                               //
 //                                                                                               //
 // This file is part of Distorted.                                                               //
 //                                                                                               //
 // Distorted is free software: you can redistribute it and/or modify                             //
 // it under the terms of the GNU General Public License as published by                          //
 // the Free Software Foundation, either version 2 of the License, or                             //
 // (at your option) any later version.                                                           //
 //                                                                                               //
 // Distorted is distributed in the hope that it will be useful,                                  //
 // but WITHOUT ANY WARRANTY; without even the implied warranty of                                //
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                                 //
 // GNU General Public License for more details.                                                  //
 //                                                                                               //
 // You should have received a copy of the GNU General Public License                             //
-// along with Distorted.  If not, see <http://www.gnu.org/licenses/>.                            //
+// along with DistortedLibrary.  If not, see <http://www.gnu.org/licenses/>.                            //
 ///////////////////////////////////////////////////////////////////////////////////////////////////
 
 package org.distorted.magic;
@@ -27,7 +27,7 @@ import android.os.Bundle;
 import android.support.v4.content.ContextCompat;
 import android.view.View;
 
-import org.distorted.library.main.Distorted;
+import org.distorted.library.main.DistortedLibrary;
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -55,7 +55,7 @@ public class RubikActivity extends Activity
       {
       GLSurfaceView view = findViewById(R.id.rubikSurfaceView);
       view.onPause();
-      Distorted.onPause();
+      DistortedLibrary.onPause();
       super.onPause();
       }
 
@@ -74,7 +74,7 @@ public class RubikActivity extends Activity
     @Override
     protected void onDestroy() 
       {
-      Distorted.onDestroy();  
+      DistortedLibrary.onDestroy();
       super.onDestroy();
       }
 
@@ -1,20 +1,20 @@
 // Copyright 2019 Leszek Koltunski                                                               //
 //                                                                                               //
-// This file is part of Distorted.                                                               //
+// This file is part of DistortedLibrary.                                                               //
 //                                                                                               //
@@ -1,20 +1,20 @@
 //                                                                                               //
-// Distorted is free software: you can redistribute it and/or modify                             //
+// DistortedLibrary is free software: you can redistribute it and/or modify                             //
 // it under the terms of the GNU General Public License as published by                          //
 // the Free Software Foundation, either version 2 of the License, or                             //
@@ -1,20 +1,20 @@
 // (at your option) any later version.                                                           //
 //                                                                                               //
-// Distorted is distributed in the hope that it will be useful,                                  //
+// DistortedLibrary is distributed in the hope that it will be useful,                                  //
 // but WITHOUT ANY WARRANTY; without even the implied warranty of                                //
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                                 //
diff --git a/src/main/java/org/distorted/magic/RubikRenderer.java b/src/main/java/org/distorted/magic/RubikRenderer.java
index b6e4d714..d73c5118 100644
--- a/src/main/java/org/distorted/magic/RubikRenderer.java
+++ b/src/main/java/org/distorted/magic/RubikRenderer.java
@@ -1,20 +1,20 @@
 ///////////////////////////////////////////////////////////////////////////////////////////////////
 // Copyright 2019 Leszek Koltunski                                                               //
 //                                                                                               //
 // This file is part of Distorted.                                                               //
 //                                                                                               //
 // Distorted is free software: you can redistribute it and/or modify                             //
 // it under the terms of the GNU General Public License as published by                          //
 // the Free Software Foundation, either version 2 of the License, or                             //
 // (at your option) any later version.                                                           //
 //                                                                                               //
 // Distorted is distributed in the hope that it will be useful,                                  //
 // but WITHOUT ANY WARRANTY; without even the implied warranty of                                //
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                                 //
 // GNU General Public License for more details.                                                  //
 //                                                                                               //
 // You should have received a copy of the GNU General Public License                             //
-// along with Distorted.  If not, see <http://www.gnu.org/licenses/>.                            //
+// along with DistortedLibrary.  If not, see <http://www.gnu.org/licenses/>.                            //
 ///////////////////////////////////////////////////////////////////////////////////////////////////
 
 package org.distorted.magic;
@@ -22,7 +22,7 @@ package org.distorted.magic;
 import android.opengl.GLSurfaceView;
 
 import org.distorted.library.effect.VertexEffectSink;
-import org.distorted.library.main.Distorted;
+import org.distorted.library.main.DistortedLibrary;
 import org.distorted.library.main.DistortedScreen;
 import org.distorted.library.message.EffectListener;
 import org.distorted.library.message.EffectMessage;
@@ -166,7 +166,7 @@ class RubikRenderer implements GLSurfaceView.Renderer, EffectListener
 
       try
         {
-        Distorted.onCreate(mView.getContext());
+        DistortedLibrary.onCreate(mView.getContext());
         }
       catch(Exception ex)
         {
@@ -1,20 +1,20 @@
 // Copyright 2019 Leszek Koltunski                                                               //
 //                                                                                               //
-// This file is part of Distorted.                                                               //
+// This file is part of DistortedLibrary.                                                               //
 //                                                                                               //
@@ -1,20 +1,20 @@
 //                                                                                               //
-// Distorted is free software: you can redistribute it and/or modify                             //
+// DistortedLibrary is free software: you can redistribute it and/or modify                             //
 // it under the terms of the GNU General Public License as published by                          //
 // the Free Software Foundation, either version 2 of the License, or                             //
@@ -1,20 +1,20 @@
 // (at your option) any later version.                                                           //
 //                                                                                               //
-// Distorted is distributed in the hope that it will be useful,                                  //
+// DistortedLibrary is distributed in the hope that it will be useful,                                  //
 // but WITHOUT ANY WARRANTY; without even the implied warranty of                                //
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                                 //